@@ -75,6 +75,15 @@ class DecoderService:
                     ):
                         token_proxies[delegator] = delegate_semantic
                         break
+
+                if potential_proxy := self.web3provider.guess_erc20_proxy(delegator):
+                    token_proxies[delegator] = (potential_proxy['name'], potential_proxy['symbol'], potential_proxy['decimals'], 'ERC20')
+                    break
+
+                if potential_proxy := self.web3provider.guess_erc721_proxy(delegator):
+                    token_proxies[delegator] = (potential_proxy['name'], potential_proxy['symbol'], 1, 'ERC721')
+                    break
+
             elif all(delegator_semantic):
                 token_proxies[delegator] = delegator_semantic
 
@@ -93,7 +102,7 @@ class DecoderService:
         )
         # read a raw block from a node
         block = Block.from_raw(
-            w3block=self.web3provider.get_block(transaction.metadata.block_number),
+            w3block=self.web3provider.get_block(transaction.metadata.block_number, chain_id),
             chain_id=chain_id,
         )
 
