@@ -37,7 +37,7 @@ class SemanticDecoder(ISemanticDecoder):
         token_proxies: Dict[str, Dict],
         chain_id: str,
     ) -> DecodedTransaction:
-        transaction.metadata = self.decode_metadata(block, transaction.metadata)
+        transaction.metadata = self.decode_metadata(block, transaction.metadata, chain_id)
         transaction.events = self.decode_events(
             transaction.events, transaction.metadata, token_proxies
         )
@@ -54,12 +54,15 @@ class SemanticDecoder(ISemanticDecoder):
         return transaction
 
     def decode_metadata(
-        self, block_metadata: BlockMetadata, tx_metadata: TransactionMetadata
+        self,
+        block_metadata: BlockMetadata,
+        tx_metadata: TransactionMetadata,
+        chain_id: str
     ) -> DecodedTransactionMetadata:
         return SemanticMetadataDecoder(repository=self.repository).decode(
             block_metadata=block_metadata,
             tx_metadata=tx_metadata,
-            chain_id=self._default_chain,
+            chain_id=chain_id,
         )
 
     def decode_event(
